@@ -18,6 +18,7 @@ logger = logging.getLogger(__name__)
 
 def run(options):
     Database = backend.get('Database')
+    main_lang = config.get('database', 'language')
     init = {}
     for db_name in options.database_names:
         init[db_name] = False
@@ -44,14 +45,13 @@ def run(options):
                 cursor.execute(*lang.select(lang.code,
                         where=lang.translatable == True))
                 lang = set([x[0] for x in cursor.fetchall()])
-            main_lang = config.get('database', 'language')
             lang.add(main_lang)
         else:
             lang = set()
         lang |= set(options.languages)
         pool = Pool(db_name)
         pool.init(update=options.update, lang=list(lang),
-            installdeps=options.installdeps)
+            activatedeps=options.activatedeps)
 
         if options.update_modules_list:
             with Transaction().start(db_name, 0) as transaction:
@@ -70,36 +70,51 @@ def run(options):
                         })
 
     for db_name in options.database_names:
-        if init[db_name] or options.password:
-            # try to read password from environment variable
-            # TRYTONPASSFILE, empty TRYTONPASSFILE ignored
-            passpath = os.getenv('TRYTONPASSFILE')
-            password = ''
-            if passpath:
-                try:
-                    with open(passpath) as passfile:
-                        password, = passfile.read().splitlines()
-                except Exception, err:
-                    sys.stderr.write('Can not read password '
-                        'from "%s": "%s"\n' % (passpath, err))
-
-            if not password:
-                while True:
-                    password = getpass('"admin" password for "%s": ' % db_name)
-                    password2 = getpass('"admin" password confirmation: ')
-                    if password != password2:
-                        sys.stderr.write('"admin" password confirmation '
-                            'doesn\'t match "admin" password.\n')
-                        continue
-                    if not password:
-                        sys.stderr.write('"admin" password is required.\n')
-                        continue
-                    break
-
-            with Transaction().start(db_name, 0) as transaction:
-                pool = Pool()
-                User = pool.get('res.user')
+        with Transaction().start(db_name, 0) as transaction:
+            pool = Pool()
+            User = pool.get('res.user')
+            Configuration = pool.get('ir.configuration')
+            configuration = Configuration(1)
+            with transaction.set_context(active_test=False):
                 admin, = User.search([('login', '=', 'admin')])
-                User.write([admin], {
-                        'password': password,
-                        })
+
+            if options.email is not None:
+                admin.email = options.email
+            elif init[db_name]:
+                admin.email = input(
+                    '"admin" email for "%s": ' % db_name)
+            if init[db_name] or options.password:
+                configuration.language = main_lang
+                # try to read password from environment variable
+                # TRYTONPASSFILE, empty TRYTONPASSFILE ignored
+                passpath = os.getenv('TRYTONPASSFILE')
+                password = ''
+                if passpath:
+                    try:
+                        with open(passpath) as passfile:
+                            password, = passfile.read().splitlines()
+                    except Exception as err:
+                        sys.stderr.write('Can not read password '
+                            'from "%s": "%s"\n' % (passpath, err))
+
+                if not password and not options.reset_password:
+                    while True:
+                        password = getpass(
+                            '"admin" password for "%s": ' % db_name)
+                        password2 = getpass('"admin" password confirmation: ')
+                        if password != password2:
+                            sys.stderr.write('"admin" password confirmation '
+                                'doesn\'t match "admin" password.\n')
+                            continue
+                        if not password:
+                            sys.stderr.write('"admin" password is required.\n')
+                            continue
+                        break
+                if not options.reset_password:
+                    admin.password = password
+            admin.save()
+            if options.reset_password:
+                User.reset_password([admin])
+            if options.hostname is not None:
+                configuration.hostname = options.hostname or None
+            configuration.save()
