@@ -1,13 +1,9 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
-import sys
 
 
 class TrytonException(Exception):
-
-    if sys.version_info < (3, ):
-        def __str__(self):
-            return unicode(self).encode('utf-8')
+    pass
 
 
 class UserError(TrytonException):
@@ -18,8 +14,8 @@ class UserError(TrytonException):
         self.description = description
         self.code = 1
 
-    def __unicode__(self):
-        return u'%s - %s' % (self.message, self.description)
+    def __str__(self):
+        return '%s - %s' % (self.message, self.description)
 
 
 class UserWarning(TrytonException):
@@ -32,8 +28,8 @@ class UserWarning(TrytonException):
         self.description = description
         self.code = 2
 
-    def __unicode__(self):
-        return u'%s - %s' % (self.message, self.description)
+    def __str__(self):
+        return '%s - %s' % (self.message, self.description)
 
 
 class LoginException(TrytonException):
@@ -58,7 +54,7 @@ class ConcurrencyException(TrytonException):
         self.message = message
         self.code = 4
 
-    def __unicode__(self):
+    def __str__(self):
         return self.message
 
 
@@ -71,5 +67,5 @@ class MissingDependenciesException(TrytonException):
     def __init__(self, missings):
         self.missings = missings
 
-    def __unicode__(self):
+    def __str__(self):
         return 'Missing dependencies: %s' % ' '.join(self.missings)
