@@ -599,9 +599,8 @@ class ActionReport(ActionMixin, ModelSQL, ModelView):
 
     @fields.depends('name', 'template_extension')
     def on_change_with_report_content_name(self, name=None):
-        if not self.name:
-            return
-        return ''.join([self.name, os.extsep, self.template_extension])
+        return ''.join(
+            filter(None, [self.name, os.extsep, self.template_extension]))
 
     @classmethod
     def get_pyson(cls, reports, name):
@@ -626,6 +625,7 @@ class ActionReport(ActionMixin, ModelSQL, ModelView):
         for report in reports:
             if report.report:
                 default['report_content'] = None
+                default['report'] = None
             default['report_name'] = report.report_name
             new_reports.extend(super(ActionReport, cls).copy([report],
                     default=default))
