@@ -11,6 +11,7 @@ class Configuration(ModelSingleton, ModelSQL):
     'Configuration'
     __name__ = 'ir.configuration'
     language = fields.Char('language')
+    hostname = fields.Char("Hostname")
     _get_language_cache = Cache('ir_configuration.get_language')
 
     @staticmethod
@@ -28,3 +29,19 @@ class Configuration(ModelSingleton, ModelSQL):
             language = config.get('database', 'language')
         cls._get_language_cache.set(None, language)
         return language
+
+    @classmethod
+    def create(cls, vlist):
+        records = super().create(vlist)
+        cls._get_language_cache.clear()
+        return records
+
+    @classmethod
+    def write(cls, *args):
+        super().write(*args)
+        cls._get_language_cache.clear()
+
+    @classmethod
+    def delete(cls, records):
+        super().delete(records)
+        cls._get_language_cache.clear()
