@@ -1,13 +1,12 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
-from __future__ import division
 
 from functools import wraps
 
 from sql.operators import NotIn
 
 from trytond.model import ModelView, ModelSQL, fields, Unique
-from trytond.modules import create_graph, get_module_list, get_module_info
+from trytond.modules import get_module_list, get_module_info
 from trytond.wizard import Wizard, StateView, Button, StateTransition, \
     StateAction
 from trytond import backend
@@ -69,34 +68,44 @@ class Module(ModelSQL, ModelView):
         cls._error_messages.update({
             'delete_state': ('You can not remove a module that is activated '
                     'or will be activated'),
-            'missing_dep': 'Missing dependencies %s for module "%s"',
             'deactivate_dep': ('Some activated modules depend on the ones '
                     'you are trying to deactivate:'),
             })
         cls._buttons.update({
                 'activate': {
                     'invisible': Eval('state') != 'not activated',
+                    'depends': ['state'],
                     },
                 'activate_cancel': {
                     'invisible': Eval('state') != 'to activate',
+                    'depends': ['state'],
                     },
                 'deactivate': {
                     'invisible': Eval('state') != 'activated',
+                    'depends': ['state'],
                     },
                 'deactivate_cancel': {
                     'invisible': Eval('state') != 'to remove',
+                    'depends': ['state'],
                     },
                 'upgrade': {
                     'invisible': Eval('state') != 'activated',
+                    'depends': ['state'],
                     },
                 'upgrade_cancel': {
                     'invisible': Eval('state') != 'to upgrade',
+                    'depends': ['state'],
                     },
                 })
 
     @classmethod
     def __register__(cls, module_name):
+        pool = Pool()
+        ModelData = pool.get('ir.model.data')
         TableHandler = backend.get('TableHandler')
+        sql_table = cls.__table__()
+        model_data_sql_table = ModelData.__table__()
+        cursor = Transaction().connection.cursor()
 
         # Migration from 3.6: remove double module
         old_table = 'ir_module_module'
@@ -106,8 +115,6 @@ class Module(ModelSQL, ModelView):
         super(Module, cls).__register__(module_name)
 
         # Migration from 4.0: rename installed to activated
-        sql_table = cls.__table__()
-        cursor = Transaction().connection.cursor()
         cursor.execute(*sql_table.update(
                 [sql_table.state], ['activated'],
                 where=sql_table.state == 'installed'))
@@ -115,6 +122,20 @@ class Module(ModelSQL, ModelView):
                 [sql_table.state], ['not activated'],
                 where=sql_table.state == 'uninstalled'))
 
+        # Migration from 4.6: register buttons on ir module
+        button_fs_ids = [
+            'module_activate_button',
+            'module_activate_cancel_button',
+            'module_deactivate_button',
+            'module_deactivate_cancel_button',
+            'module_upgrade_button',
+            'module_upgrade_cancel_button',
+            ]
+        cursor.execute(*model_data_sql_table.update(
+                [model_data_sql_table.module], ['ir'],
+                where=((model_data_sql_table.module == 'res')
+                    & (model_data_sql_table.fs_id.in_(button_fs_ids)))))
+
     @staticmethod
     def default_state():
         return 'not activated'
@@ -138,7 +159,7 @@ class Module(ModelSQL, ModelView):
         child_ids = dict((m.id, []) for m in modules)
         name2id = dict((m.name, m.id) for m in modules)
         childs = cls.search([
-                ('dependencies.name', 'in', name2id.keys()),
+                ('dependencies.name', 'in', list(name2id.keys())),
                 ])
         for child in childs:
             for dep in child.dependencies:
@@ -184,7 +205,6 @@ class Module(ModelSQL, ModelView):
     @filter_state('not activated')
     def activate(cls, modules):
         modules_activated = set(modules)
-        graph, packages, later = create_graph(get_module_list())
 
         def get_parents(module):
             parents = set(p for p in module.parents)
@@ -193,13 +213,6 @@ class Module(ModelSQL, ModelView):
             return parents
 
         for module in modules:
-            if module.name not in graph:
-                missings = []
-                for package, deps, xdep, info in packages:
-                    if package == module.name:
-                        missings = [x for x in deps if x not in graph]
-                cls.raise_user_error('missing_dep', (missings, module.name))
-
             modules_activated.update((m for m in get_parents(module)
                     if m.state == 'not activated'))
         cls.write(list(modules_activated), {
@@ -211,7 +224,6 @@ class Module(ModelSQL, ModelView):
     @filter_state('activated')
     def upgrade(cls, modules):
         modules_activated = set(modules)
-        graph, packages, later = create_graph(get_module_list())
 
         def get_childs(module):
             childs = set(c for c in module.childs)
@@ -220,13 +232,6 @@ class Module(ModelSQL, ModelView):
             return childs
 
         for module in modules:
-            if module.name not in graph:
-                missings = []
-                for package, deps, xdep, info in packages:
-                    if package == module.name:
-                        missings = [x for x in deps if x not in graph]
-                cls.raise_user_error('missing_dep', (missings, module.name))
-
             modules_activated.update((m for m in get_childs(module)
                     if m.state == 'activated'))
         cls.write(list(modules_activated), {
@@ -284,14 +289,14 @@ class Module(ModelSQL, ModelView):
         module_names = get_module_list()
 
         modules = cls.search([])
-        name2module = dict((m.name, m) for m in modules)
+        name2id = dict((m.name, m.id) for m in modules)
         cls.delete([m for m in modules
                 if m.state != 'activated' and m.name not in module_names])
 
         # iterate through activated modules and mark them as being so
         for name in module_names:
-            if name in name2module:
-                module = name2module[name]
+            if name in name2id:
+                module = cls(name2id[name])
                 tryton = get_module_info(name)
                 cls._update_dependencies(module, tryton.get('depends', []))
                 continue
@@ -410,11 +415,6 @@ class ModuleConfigWizardItem(ModelSQL, ModelView):
                 where=(model_data.model ==
                     'ir.module.module.config_wizard.item')))
 
-        table = TableHandler(cls, module_name)
-
-        # Migrate from 2.2 remove name
-        table.drop_column('name')
-
         super(ModuleConfigWizardItem, cls).__register__(module_name)
 
     @staticmethod
@@ -486,7 +486,7 @@ class ModuleConfigWizard(Wizard):
     other = StateView('ir.module.config_wizard.other',
         'ir.module_config_wizard_other_view_form', [
             Button('Cancel', 'end', 'tryton-cancel'),
-            Button('Next', 'action', 'tryton-go-next', default=True),
+            Button('Next', 'action', 'tryton-forward', default=True),
             ])
     action = ConfigStateAction()
     done = StateView('ir.module.config_wizard.done',
