@@ -2,10 +2,10 @@
 # this repository contains the full copyright notices and license terms.
 from string import Template
 import time
-from itertools import izip
+
 from sql import Literal, For
 
-from ..model import ModelView, ModelSQL, fields, Check
+from ..model import ModelView, ModelSQL, DeactivableMixin, fields, Check
 from ..tools import datetime_strftime
 from ..pyson import Eval, And
 from ..transaction import Transaction
@@ -27,7 +27,7 @@ class SequenceType(ModelSQL, ModelView):
     code = fields.Char('Sequence Code', required=True)
 
 
-class Sequence(ModelSQL, ModelView):
+class Sequence(DeactivableMixin, ModelSQL, ModelView):
     "Sequence"
     __name__ = 'ir.sequence'
 
@@ -37,7 +37,6 @@ class Sequence(ModelSQL, ModelView):
         states={
             'readonly': Eval('context', {}).contains('code'),
             })
-    active = fields.Boolean('Active')
     prefix = fields.Char('Prefix')
     suffix = fields.Char('Suffix')
     type = fields.Selection([
@@ -100,31 +99,6 @@ class Sequence(ModelSQL, ModelView):
                     'future on sequence "%s".'),
                 })
 
-    @classmethod
-    def __register__(cls, module_name):
-        TableHandler = backend.get('TableHandler')
-        table = TableHandler(cls, module_name)
-        transaction = Transaction()
-
-        # Migration from 2.0 rename number_next into number_next_internal
-        table.column_rename('number_next', 'number_next_internal')
-
-        super(Sequence, cls).__register__(module_name)
-
-        # Migration from 2.0 create sql_sequence
-        if sql_sequence and not cls._strict:
-            sequences = cls.search([])
-            for sequence in sequences:
-                if sequence.type != 'incremental':
-                    continue
-                if not transaction.database.sequence_exist(
-                        transaction.connection, sequence._sql_sequence_name):
-                    sequence.create_sql_sequence(sequence.number_next_internal)
-
-    @staticmethod
-    def default_active():
-        return True
-
     @staticmethod
     def default_type():
         return 'incremental'
@@ -189,7 +163,7 @@ class Sequence(ModelSQL, ModelView):
     @classmethod
     def create(cls, vlist):
         sequences = super(Sequence, cls).create(vlist)
-        for sequence, values in izip(sequences, vlist):
+        for sequence, values in zip(sequences, vlist):
             if sql_sequence and not cls._strict:
                 sequence.update_sql_sequence(values.get('number_next',
                         cls.default_number_next()))
@@ -232,9 +206,8 @@ class Sequence(ModelSQL, ModelView):
             for fix, error_message in ((sequence.prefix, 'invalid_prefix'),
                     (sequence.suffix, 'invalid_suffix')):
                 try:
-                    cls._process(sequence.prefix)
-                    cls._process(sequence.suffix)
-                except Exception:
+                    cls._process(fix)
+                except (TypeError, ValueError):
                     cls.raise_user_error(error_message, {
                             'prefix': fix,
                             'sequence': sequence.rec_name,
@@ -357,7 +330,7 @@ class Sequence(ModelSQL, ModelView):
         '''
         if isinstance(domain, cls):
             domain = domain.id
-        if isinstance(domain, (int, long)):
+        if isinstance(domain, int):
             domain = [('id', '=', domain)]
 
         # bypass rules on sequences
