@@ -76,7 +76,7 @@ class Translation(ModelSQL, ModelView):
     overriding_module = fields.Char('Overriding Module', readonly=True)
     _translation_cache = Cache('ir.translation', size_limit=10240,
         context=False)
-    _get_language_cache = Cache('ir.translation')
+    _get_language_cache = Cache('ir.translation.get_language')
 
     @classmethod
     def __setup__(cls):
@@ -496,12 +496,16 @@ class Translation(ModelSQL, ModelView):
                 to_save = []
                 for record, value in zip(records, values):
                     translation = translations.get(get_name(record))
+                    if lang == 'en':
+                        src = value
+                    else:
+                        src = getattr(record, field_name)
                     if not translation:
                         translation = cls()
                         translation.name = name
                         translation.lang = lang
                         translation.type = ttype
-                    translation.src = getattr(record, field_name)
+                    translation.src = src
                     translation.value = value
                     translation.fuzzy = False
                     to_save.append(translation)
@@ -537,6 +541,10 @@ class Translation(ModelSQL, ModelView):
             to_save = []
             for record, value in zip(records, values):
                 translation = translations.get(record.id)
+                if lang == Config.get_language():
+                    src = value
+                else:
+                    src = getattr(record, field_name)
                 if not translation:
                     translation = cls()
                     translation.name = name
@@ -544,19 +552,14 @@ class Translation(ModelSQL, ModelView):
                     translation.type = ttype
                     translation.res_id = record.id
                 else:
-                    cls.write([translation], {
-                        'value': value,
-                        'src': getattr(record, field_name),
-                        'fuzzy': False,
-                        })
                     other_langs = other_translations.get(record.id)
                     if other_langs:
                         for other_lang in other_langs:
-                            other_lang.src = getattr(record, field_name)
+                            other_lang.src = src
                             other_lang.fuzzy = True
                             to_save.append(other_lang)
                 translation.value = value
-                translation.src = getattr(record, field_name)
+                translation.src = src
                 translation.fuzzy = False
                 to_save.append(translation)
             cls.save(to_save)
