@@ -4,7 +4,7 @@ import warnings
 from functools import wraps
 
 from sql import (operators, Column, Literal, Select, CombiningQuery, Null,
-    Query, Expression)
+    Query, Expression, Cast)
 from sql.conditionals import Coalesce, NullIf
 from sql.operators import Concat
 
@@ -25,13 +25,13 @@ def domain_validate(value):
 
     def test_domain(dom):
         for arg in dom:
-            if isinstance(arg, basestring):
+            if isinstance(arg, str):
                 if arg not in ('AND', 'OR'):
                     return False
             elif (isinstance(arg, tuple)
                 or (isinstance(arg, list)
                     and len(arg) > 2
-                    and ((isinstance(arg[1], basestring)
+                    and ((isinstance(arg[1], str)
                                 and arg[1] in OPERATORS)
                         or (isinstance(arg[1], PYSON)
                                 and arg[1].types() == set([str]))))):
@@ -71,6 +71,13 @@ def size_validate(value):
                 'size must return integer'
 
 
+def search_order_validate(value):
+    if value is not None:
+        assert isinstance(value, (list, PYSON)), 'search_order must be PYSON'
+        if hasattr(value, 'types'):
+            assert value.types() == set([list]), 'search_order must be PYSON'
+
+
 def _set_value(record, field):
     try:
         field, nested = field.split('.', 1)
@@ -79,7 +86,10 @@ def _set_value(record, field):
     if field.startswith('_parent_'):
         field = field[8:]  # Strip '_parent_'
     if not hasattr(record, field):
-        setattr(record, field, None)
+        default = None
+        if hasattr(record, '_defaults') and field in record._defaults:
+            default = record._defaults[field]()
+        setattr(record, field, default)
     elif nested:
         parent = getattr(record, field)
         if parent:
@@ -158,6 +168,14 @@ def on_change_result(record):
     return record._changed_values
 
 
+def with_inactive_records(func):
+    @wraps(func)
+    def wrapper(*args, **kwargs):
+        with Transaction().set_context(active_test=False):
+            return func(*args, **kwargs)
+    return wrapper
+
+
 SQL_OPERATORS = {
     '=': operators.Equal,
     '!=': operators.NotEqual,
@@ -300,9 +318,15 @@ class Field(object):
         database = Transaction().database
         return database.sql_type(self._sql_type)
 
+    def sql_cast(self, expression):
+        return Cast(expression, self.sql_type().base)
+
     def sql_column(self, table):
         return Column(table, self.name)
 
+    def _domain_column(self, operator, column):
+        return column
+
     def _domain_value(self, operator, value):
         if isinstance(value, (Select, CombiningQuery)):
             return value
@@ -331,6 +355,7 @@ class Field(object):
             return method(domain, tables)
         Operator = SQL_OPERATORS[operator]
         column = self.sql_column(table)
+        column = self._domain_column(operator, column)
         expression = Operator(column, self._domain_value(operator, value))
         if isinstance(expression, operators.In) and not expression.right:
             expression = Literal(False)
@@ -398,7 +423,7 @@ class FieldTranslate(Field):
                 & (translation.fuzzy == False))
 
     def convert_domain(self, domain, tables, Model):
-        from trytond.tools import get_parent_language
+        from trytond.ir.lang import get_parent_language
         pool = Pool()
         Translation = pool.get('ir.translation')
         IrModel = pool.get('ir.model')
@@ -418,6 +443,7 @@ class FieldTranslate(Field):
             column = Coalesce(NullIf(column, ''), translation.value)
             language = get_parent_language(language)
         column = Coalesce(NullIf(column, ''), self.sql_column(table))
+        column = self._domain_column(operator, column)
         Operator = SQL_OPERATORS[operator]
         assert name == self.name
         where = Operator(column, self._domain_value(operator, value))
@@ -429,7 +455,7 @@ class FieldTranslate(Field):
         return tables[None][0].id.in_(join.select(table.id, where=where))
 
     def convert_order(self, name, tables, Model):
-        from trytond.tools import get_parent_language
+        from trytond.ir.lang import get_parent_language
         pool = Pool()
         Translation = pool.get('ir.translation')
         IrModel = pool.get('ir.model')
