@@ -24,9 +24,9 @@ class Numeric(Float):
     def sql_format(self, value):
         if value is None:
             return None
-        if isinstance(value, (int, long)):
+        if isinstance(value, int):
             value = Decimal(str(value))
-        assert isinstance(value, Decimal)
+        value = Decimal(value)
         return value
 
     def sql_column(self, table):
