@@ -5,7 +5,8 @@ from sql import Cast, Literal
 from sql.functions import Substring, Position
 from sql.conditionals import Coalesce
 
-from .field import Field, size_validate, instanciate_values, domain_validate
+from .field import (Field, size_validate, instanciate_values, domain_validate,
+    search_order_validate, context_validate)
 from ...pool import Pool
 from ...tools import grouped_slice
 from ...transaction import Transaction
@@ -18,10 +19,10 @@ class One2Many(Field):
     _type = 'one2many'
 
     def __init__(self, model_name, field, string='', add_remove=None,
-            order=None, datetime_field=None, size=None, help='',
-            required=False, readonly=False, domain=None, filter=None,
-            states=None, on_change=None, on_change_with=None, depends=None,
-            context=None, loading='lazy'):
+            order=None, datetime_field=None, size=None, search_order=None,
+            search_context=None, help='', required=False, readonly=False,
+            domain=None, filter=None, states=None, on_change=None,
+            on_change_with=None, depends=None, context=None, loading='lazy'):
         '''
         :param model_name: The name of the target model.
         :param field: The name of the field that handle the reverse many2one or
@@ -33,6 +34,8 @@ class One2Many(Field):
             allowing to specify the order of result.
         :param datetime_field: The name of the field that contains the datetime
             value to read the target records.
+        :param search_order: The order to use when searching for records
+        :param search_context: The context to use when searching for a record
         :param filter: A domain to filter target records.
         '''
         if datetime_field:
@@ -52,6 +55,10 @@ class One2Many(Field):
         self.datetime_field = datetime_field
         self.__size = None
         self.size = size
+        self.__search_order = None
+        self.search_order = search_order
+        self.__search_context = None
+        self.search_context = search_context or {}
         self.__filter = None
         self.filter = filter
 
@@ -76,6 +83,24 @@ class One2Many(Field):
 
     size = property(_get_size, _set_size)
 
+    @property
+    def search_order(self):
+        return self.__search_order
+
+    @search_order.setter
+    def search_order(self, value):
+        search_order_validate(value)
+        self.__search_order = value
+
+    @property
+    def search_context(self):
+        return self.__search_context
+
+    @search_context.setter
+    def search_context(self, value):
+        context_validate(value)
+        self.__search_context = value
+
     def sql_type(self):
         return None
 
@@ -115,7 +140,7 @@ class One2Many(Field):
         for target in targets:
             origin_id = getattr(target, self.field).id
             res[origin_id].append(target.id)
-        return dict((key, tuple(value)) for key, value in res.iteritems())
+        return dict((key, tuple(value)) for key, value in res.items())
 
     def set(self, Model, name, ids, values, *args):
         '''
@@ -164,7 +189,7 @@ class One2Many(Field):
             to_delete.extend(Target.browse(target_ids))
 
         def add(ids, target_ids):
-            target_ids = map(int, target_ids)
+            target_ids = list(map(int, target_ids))
             if not target_ids:
                 return
             targets = Target.browse(target_ids)
@@ -174,7 +199,7 @@ class One2Many(Field):
                             }))
 
         def remove(ids, target_ids):
-            target_ids = map(int, target_ids)
+            target_ids = list(map(int, target_ids))
             if not target_ids:
                 return
             for sub_ids in grouped_slice(target_ids):
@@ -187,7 +212,7 @@ class One2Many(Field):
                             }))
 
         def copy(ids, copy_ids, default=None):
-            copy_ids = map(int, copy_ids)
+            copy_ids = list(map(int, copy_ids))
 
             if default is None:
                 default = {}
@@ -272,7 +297,7 @@ class One2Many(Field):
                     return ~expression
                 return expression
             else:
-                if isinstance(value, basestring):
+                if isinstance(value, str):
                     target_name = 'rec_name'
                 else:
                     target_name = 'id'
