@@ -2,6 +2,7 @@
 # this repository contains the full copyright notices and license terms.
 import datetime
 import os
+import inspect
 import logging
 import subprocess
 import tempfile
@@ -306,7 +307,8 @@ class Report(URLMixin, PoolBase):
         path = os.path.join(
             dtemp, report.report_name + os.extsep + input_format)
         oext = FORMAT2EXT.get(output_format, output_format)
-        with open(path, 'wb+') as fp:
+        mode = 'w+' if isinstance(data, str) else 'wb+'
+        with open(path, mode) as fp:
             fp.write(data)
         try:
             cmd = ['soffice',
@@ -362,7 +364,7 @@ def get_email(report, record, languages):
     pool = Pool()
     ActionReport = pool.get('ir.action.report')
     report_id = None
-    if isinstance(report, Report):
+    if inspect.isclass(report) and issubclass(report, Report):
         Report_ = report
     else:
         if isinstance(report, ActionReport):
