@@ -27,7 +27,6 @@ def register():
         ModelButtonRule,
         ModelButtonClick,
         RuleGroupGroup,
-        RuleGroupUser,
         Lang,
         SequenceType,
         SequenceTypeGroup,
@@ -38,3 +37,6 @@ def register():
     Pool.register(
         UserConfig,
         module="res", type_='wizard')
+    Pool.register(
+        EmailResetPassword,
+        module='res', type_='report')
